@@ -192,7 +192,7 @@ class solver():
                     dilution_rate = self.models_dict[model_name].dilrate
                     derivative['d'] = self.states_var[state_name] * var[model_mu] - self.states_var[
                         state_name] * dilution_rate
-            elif self.derivatives_description[state_name] == '0':
+            elif self.derivatives_description[state_name] == '0' or self.derivatives_description[state_name] == 0:
                 pass
             elif state_name in derivatives_keys:  # 要求计算这种物质时间导数  3.28 添加功能，也可以识别没有修改过的反应->完成
                 # derivative = 0
@@ -202,8 +202,9 @@ class solver():
                 reactions = globals()
                 for item in items:
                     if item != '':
-                        model_name = item.split("_", 1)[0]
-                        flux_name = item.split("_", 1)[1]
+                        item = item.strip()
+                        model_name = (item.split("_", 1)[0])
+                        flux_name = (item.split("_", 1)[1])
 
                         model_weight = 'x_' + model_name
                         item_temp = model_name + '_M_' + flux_name
@@ -211,7 +212,9 @@ class solver():
                         if item_temp in reactions.keys():
                             exec('var[item] =' + model_weight + '*' + item_temp)
                         else:
-                            flux = var[model_name + '_solution'].fluxes[flux_name]
+                            print(model_name)
+                            print(flux_name)
+                            flux = var[model_name + '_solution'].fluxes['%s' % flux_name]
                             exec('var[item] =' + model_weight + '* flux')
                 exec("derivative['d']=" + derivative_description)
             # print("%s导数: %f" % (state_name, derivative['d']))
